Webstack-django-sorting Changelog
=================================

v2.0.0
------

Released on February 23th, 2021

- Python v3.6+ only
- Remove support of Django <1.8
- Major cleanup of code
- Jinja2 support
- Merge setup.py and setup.cfg in setup.cfg
- Provide pyproject.toml

v1.0.2
------

Released on September 23th 2020

- Fix cache issue with translatable anchors. Thanks Kim Wong.
- Updated README.md

v1.0.1
------

Released on March 1st 2017

- Improved README
- Don't return None when queryset is empty (closes #8)

v1.0.0
------

Released on January 24th 2017

- Now switching between ascending, descending, and no sorting
- Removed webstack_django_sorting.middleware.SortingMiddleware
- Fixed sorting on edge cases
- Django 1.10 support
- Improved Python 3 support
- Add first tests

v0.5.0
------

Released on January 3rd 2017

- Restore compatibility with Django v1.8 and lower
- Fix reading of README.rst with Python 3
- Cleanup in test project

v0.4.3
------

Released on December 10th 2016

- Compatibility with Django v1.9
- Better MANIFEST.in
